@@ -120,6 +120,7 @@ class NodeType(Enum):
     GlobalMaxPooling1D = "GlobalMaxPooling1D"
     GlobalMaxPooling2D = "GlobalMaxPooling2D"
     GlobalMaxPooling3D = "GlobalMaxPooling3D"
+    GroupNormalization = "GroupNormalization"
     IntegerLookup = "IntegerLookup"
     LSTM = "LSTM"
     LSTMCell = "LSTMCell"
@@ -129,6 +130,8 @@ class NodeType(Enum):
     LSTMV2 = "LSTMV2"
     LayerNormalization = "LayerNormalization"
     LeakyReLU = "LeakyReLU"
+    LocallyConnected1D = "LocallyConnected1D"
+    LocallyConnected2D = "LocallyConnected2D"
     Masking = "Masking"
     MaxPooling1D = "MaxPooling1D"
     MaxPooling2D = "MaxPooling2D"
@@ -140,6 +143,7 @@ class NodeType(Enum):
     Normalization = "Normalization"
     PReLU = "PReLU"
     Permute = "Permute"
+    RandomBrightness = "RandomBrightness"
     RandomContrast = "RandomContrast"
     RandomCrop = "RandomCrop"
     RandomFlip = "RandomFlip"
@@ -167,6 +171,7 @@ class NodeType(Enum):
     TextVectorization = "TextVectorization"
     ThresholdedReLU = "ThresholdedReLU"
     TimeDistributed = "TimeDistributed"
+    UnitNormalization = "UnitNormalization"
     UpSampling1D = "UpSampling1D"
     UpSampling2D = "UpSampling2D"
     UpSampling3D = "UpSampling3D"
@@ -890,6 +895,22 @@ class GlobalMaxPooling3D:
     type: NodeType
 
 
+@dataclass
+class GroupNormalization:
+    groups: int
+    axis: int
+    epsilon: float
+    center: bool
+    scale: bool
+    beta_initializer: InitializersEnum
+    gamma_initializer: InitializersEnum
+    beta_regularizer: RegularizerEnum
+    gamma_regularizer: RegularizerEnum
+    beta_constraint: ConstraintEnum
+    gamma_constraint: ConstraintEnum
+    type: NodeType
+
+
 @dataclass
 class IntegerLookup:
     max_tokens: List[int]
@@ -1073,6 +1094,44 @@ class LeakyReLU:
     type: NodeType
 
 
+@dataclass
+class LocallyConnected1D:
+    filters: int
+    kernel_size: List[int]
+    strides: int
+    padding: PaddingEnum
+    activation: ActivationsEnum
+    use_bias: bool
+    kernel_initializer: InitializersEnum
+    bias_initializer: InitializersEnum
+    kernel_regularizer: RegularizerEnum
+    bias_regularizer: RegularizerEnum
+    activity_regularizer: RegularizerEnum
+    kernel_constraint: ConstraintEnum
+    bias_constraint: ConstraintEnum
+    implementation: int
+    type: NodeType
+
+
+@dataclass
+class LocallyConnected2D:
+    filters: int
+    kernel_size: List[int]
+    strides: List[int]
+    padding: PaddingEnum
+    activation: ActivationsEnum
+    use_bias: bool
+    kernel_initializer: InitializersEnum
+    bias_initializer: InitializersEnum
+    kernel_regularizer: RegularizerEnum
+    bias_regularizer: RegularizerEnum
+    activity_regularizer: RegularizerEnum
+    kernel_constraint: ConstraintEnum
+    bias_constraint: ConstraintEnum
+    implementation: int
+    type: NodeType
+
+
 @dataclass
 class Masking:
     mask_value: float
@@ -1142,6 +1201,7 @@ class Normalization:
     axis: int
     mean: List[int]
     variance: List[int]
+    invert: bool
     type: NodeType
 
 
@@ -1160,6 +1220,14 @@ class Permute:
     type: NodeType
 
 
+@dataclass
+class RandomBrightness:
+    factor: List[int]
+    value_range: List[int]
+    seed: List[int]
+    type: NodeType
+
+
 @dataclass
 class RandomContrast:
     factor: List[int]
@@ -1390,7 +1458,7 @@ class StringLookup:
     oov_token: str
     vocabulary: List[int]
     idf_weights: List[int]
-    encoding: List[int]
+    encoding: str
     invert: bool
     output_mode: str
     sparse: bool
@@ -1434,6 +1502,7 @@ class TextVectorization:
     idf_weights: List[int]
     sparse: bool
     ragged: bool
+    encoding: str
     type: NodeType
 
 
@@ -1448,6 +1517,12 @@ class TimeDistributed:
     type: NodeType
 
 
+@dataclass
+class UnitNormalization:
+    axis: int
+    type: NodeType
+
+
 @dataclass
 class UpSampling1D:
     size: int
@@ -1495,6 +1570,8 @@ class BinaryCrossentropy:
 
 @dataclass
 class BinaryFocalCrossentropy:
+    apply_class_balancing: bool
+    alpha: float
     gamma: float
     from_logits: bool
     label_smoothing: float
@@ -1577,6 +1654,14 @@ class Adadelta:
     learning_rate: float
     rho: float
     epsilon: float
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1585,6 +1670,14 @@ class Adagrad:
     learning_rate: float
     initial_accumulator_value: float
     epsilon: float
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1595,6 +1688,14 @@ class Adam:
     beta_2: float
     epsilon: float
     amsgrad: bool
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1604,6 +1705,14 @@ class Adamax:
     beta_1: float
     beta_2: float
     epsilon: float
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1616,6 +1725,14 @@ class Ftrl:
     l2_regularization_strength: float
     l2_shrinkage_regularization_strength: float
     beta: float
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1625,6 +1742,14 @@ class Nadam:
     beta_1: float
     beta_2: float
     epsilon: float
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1635,6 +1760,14 @@ class RMSprop:
     momentum: float
     epsilon: float
     centered: bool
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: int
+    jit_compile: bool
     type: NodeType
 
 
@@ -1643,6 +1776,15 @@ class SGD:
     learning_rate: float
     momentum: float
     nesterov: bool
+    amsgrad: bool
+    weight_decay: List[int]
+    clipnorm: List[int]
+    clipvalue: List[int]
+    global_clipnorm: List[int]
+    use_ema: bool
+    ema_momentum: float
+    ema_overwrite_frequency: List[int]
+    jit_compile: bool
     type: NodeType
 
 
@@ -1756,13 +1898,14 @@ class NodeDataTypes:
                  DepthwiseConv1D, DepthwiseConv2D, Discretization, Dot, Dropout, ELU, Embedding, Flatten, GRU, GRUCell, 
                  GRUCellV1, GRUCellV2, GRUV1, GRUV2, GaussianDropout, GaussianNoise, GlobalAveragePooling1D, 
                  GlobalAveragePooling2D, GlobalAveragePooling3D, GlobalMaxPooling1D, GlobalMaxPooling2D, 
-                 GlobalMaxPooling3D, IntegerLookup, LSTM, LSTMCell, LSTMCellV1, LSTMCellV2, LSTMV1, LSTMV2, 
-                 LayerNormalization, LeakyReLU, Masking, MaxPooling1D, MaxPooling2D, MaxPooling3D, Maximum, Minimum, 
-                 MultiHeadAttention, Multiply, Normalization, PReLU, Permute, RandomContrast, RandomCrop, RandomFlip, 
-                 RandomFourierFeatures, RandomHeight, RandomRotation, RandomTranslation, RandomWidth, RandomZoom, ReLU, 
-                 RepeatVector, Reshape, Resizing, SeparableConv1D, SeparableConv2D, SimpleRNN, SimpleRNNCell, Softmax, 
-                 SpatialDropout1D, SpatialDropout2D, SpatialDropout3D, StringLookup, Subtract, SyncBatchNormalization, 
-                 TextVectorization, ThresholdedReLU, TimeDistributed, UpSampling1D, UpSampling2D, UpSampling3D, 
+                 GlobalMaxPooling3D, GroupNormalization, IntegerLookup, LSTM, LSTMCell, LSTMCellV1, LSTMCellV2, LSTMV1, 
+                 LSTMV2, LayerNormalization, LeakyReLU, LocallyConnected1D, LocallyConnected2D, Masking, MaxPooling1D, 
+                 MaxPooling2D, MaxPooling3D, Maximum, Minimum, MultiHeadAttention, Multiply, Normalization, PReLU, 
+                 Permute, RandomBrightness, RandomContrast, RandomCrop, RandomFlip, RandomFourierFeatures, RandomHeight, 
+                 RandomRotation, RandomTranslation, RandomWidth, RandomZoom, ReLU, RepeatVector, Reshape, Resizing, 
+                 SeparableConv1D, SeparableConv2D, SimpleRNN, SimpleRNNCell, Softmax, SpatialDropout1D, 
+                 SpatialDropout2D, SpatialDropout3D, StringLookup, Subtract, SyncBatchNormalization, TextVectorization, 
+                 ThresholdedReLU, TimeDistributed, UnitNormalization, UpSampling1D, UpSampling2D, UpSampling3D, 
                  ZeroPadding1D, ZeroPadding2D, ZeroPadding3D, BinaryCrossentropy, BinaryFocalCrossentropy, 
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
